<?php
namespace ElementorGillionElements\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Core\Schemes\Typography;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Frontend;
use vcAuthor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor - Blog Posts
 */
class Gillion_Author extends Widget_Base {

	/**
	 * Adds scripts
	 */
	public function __construct($data = [], $args = null) {
       parent::__construct($data, $args);
    }

	/**
	 * Retrieve the widget name.
	 */
	public function get_name() {
		return 'gillion-author';
	}

	/**
	 * Retrieve the widget title.
	 */
	public function get_title() {
		return esc_attr__( 'Blog Author', 'gillion' );
	}


	/**
	 * Retrieve the widget icon.
	 */
	public function get_icon() {
		return 'fas fa-user-edit';
	}


	/**
	 * Retrieve the list of categories the widget belongs to.
	 */
	public function get_categories() {
		return [ 'gillion' ];
	}


	/**
	 * Register the widget controls.
	 */
	protected function register_controls() {
        $this->start_controls_section(
            'section_content',
            [
                'label' => esc_attr__( 'Content', 'gillion' ),
            ]
        );

                $this->add_control(
                    'author_username',
                    [
                        'label' => esc_attr__( 'Author Username or ID', 'gillion' ),
                        'description' => __( 'Enter author username or ID', 'gillion' ) . ' <a href="'.esc_url( admin_url( '/users.php' ) ).'" target="_blank">(get here)</a>',
                        'type' => Controls_Manager::TEXT,

                    ]
                );


                $this->add_control(
                    'author_posts',
                    [
                        'label' => esc_attr__( 'Author Posts Count', 'gillion' ),
                        'description' => esc_attr__( 'Choose slider information fields', 'gillion' ),
                        'type' => Controls_Manager::SELECT,
                        'options' => [
                            'off' => esc_attr__( 'Off', 'gillion' ),
                            'on' => esc_attr__( 'On', 'gillion' ),
                        ],
                        'default' => 'off',

                    ]
                );


        $this->end_controls_section();
	}


	/**
	 * Render the widget output on the frontend.
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$settings = (array)$settings;
		$settings['elementor'] = true;
		vcAuthor::_html( $settings );
	}
}
