<?php
namespace ElementorGillionElements\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Core\Schemes\Typography;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Frontend;
use vcBlogPosts;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor - Blog Posts
 */
class Gillion_Blog_Posts_Basic extends Widget_Base {

	/**
	 * Adds scripts
	 */
	public function __construct($data = [], $args = null) {
       parent::__construct($data, $args);
    }

	/**
	 * Retrieve the widget name.
	 */
	public function get_name() {
		return 'gillion-blog-posts-basic';
	}

	/**
	 * Retrieve the widget title.
	 */
	public function get_title() {
		return esc_attr__( 'Blog Posts Basic', 'gillion' );
	}


	/**
	 * Retrieve the widget icon.
	 */
	public function get_icon() {
		return 'fas fa-pencil-alt';
	}


	/**
	 * Retrieve the list of categories the widget belongs to.
	 */
	public function get_categories() {
		return [ 'gillion' ];
	}


	/**
	 * Register the widget controls.
	 */
	protected function register_controls() {
        $this->start_controls_section(
            'section_content',
            [
                'label' => esc_attr__( 'Content', 'gillion' ),
            ]
        );

                $this->add_control(
                    'style',
                    [
                        'label' => esc_attr__( 'Posts Style', 'gillion' ),
                        'description' => esc_attr__( 'Choose posts style', 'gillion' ),
                        'type' => Controls_Manager::SELECT,
                        'options' => [
                            'grid' => esc_attr__( 'Grid', 'gillion' ),
                            'masonry' => esc_attr__( 'Masonry', 'gillion' ),
                            'masonry blog-style-masonry-card' => esc_attr__( 'Masonry Card', 'gillion' ),
                            'left-small' => esc_attr__( 'Left', 'gillion' ),
                            'left-mini' => esc_attr__( 'Left (mini)', 'gillion' ),
                            'left' => esc_attr__( 'Left (large)', 'gillion' ),
                            'left-right' => esc_attr__( 'Left/Right Mix', 'gillion' ),
                            'left-right blog-style-left-right-small' => esc_attr__( 'Left/Right Mix (small without description)', 'gillion' ),
                            'left-right blog-style-left-right-large' => esc_attr__( 'Left/Right Mix (large)', 'gillion' ),
                            'large' => esc_attr__( 'Large (title at the top)', 'gillion' ),
                            'large large-title-bellow' => esc_attr__( 'Large (title bellow the image)', 'gillion' ),
                            'large large-centered' => esc_attr__( 'Large (centered)', 'gillion' ),
                        ],
                        'default' => 'grid',
                    ]
                );

                $this->add_control(
                    'columns',
                    [
                        'label' => esc_attr__( 'Posts Columns', 'gillion' ),
                        'description' => esc_attr__( '', 'gillion' ),
                        'type' => Controls_Manager::SELECT,
                        'options' => [
                            '2' => esc_attr__( '2 Columns', 'gillion' ),
                            '3' => esc_attr__( '3 Columns', 'gillion' ),
                            '4' => esc_attr__( '4 Columns', 'gillion' ),
                        ],
                        'default' => '2',
                    ]
                );

                $this->add_control(
                    'limit',
                    [
                        'label' => esc_attr__( 'Posts Limit', 'gillion' ),
                        'description' => esc_attr__( 'Choose posts limit', 'gillion' ),
                        'type' => Controls_Manager::TEXT,
                        'default' => '2',
                    ]
                );

                $this->add_control(
                    'offset',
                    [
                        'label' => esc_attr__( 'Posts Offset', 'gillion' ),
                        'description' => esc_attr__( 'Enter posts offset number (will be disabled if specific posts will be entered)', 'gillion' ),
                        'type' => Controls_Manager::TEXT,
                    ]
                );

                $this->add_control(
                    'posts',
                    [
                        'label' => esc_attr__( 'Show Only Specific Posts', 'gillion' ),
                        'description' => esc_attr__( 'Enter post IDs with comma, like: 1,2,3,4,5', 'gillion' ),
                        'type' => Controls_Manager::TEXT,
                    ]
                );

                $this->add_control(
                    'categories',
                    [
                        'label' => esc_attr__( 'Show Only Specific Categories', 'gillion' ),
                        'description' => esc_attr__( 'Enter categories by names to narrow output (Note: only listed categories will be displayed, divide categories with linebreak (Enter)).', 'gillion' ),
                        'type' => Controls_Manager::TEXTAREA,
                    ]
                );

                $this->add_control(
                    'order_by',
                    [
                        'label' => esc_attr__( 'Order By', 'gillion' ),
                        'description' => esc_attr__( '', 'gillion' ),
                        'type' => Controls_Manager::SELECT,
                        'options' => [
                            'date' => esc_attr__( 'Date', 'gillion' ),
                            'name' => esc_attr__( 'Name', 'gillion' ),
                            'author' => esc_attr__( 'Author', 'gillion' ),
                            'rand' => esc_attr__( 'Random', 'gillion' ),
                            'comment_count' => esc_attr__( 'Comment Count', 'gillion' ),
                        ],
                        'default' => 'date',
                    ]
                );

                $this->add_control(
                    'order2',
                    [
                        'label' => esc_attr__( 'Order', 'gillion' ),
                        'description' => esc_attr__( '', 'gillion' ),
                        'type' => Controls_Manager::SELECT,
                        'options' => [
                            'DESC' => esc_attr__( 'Descending', 'gillion' ),
                            'ASC' => esc_attr__( 'Ascending', 'gillion' ),
                        ],
                        'default' => 'DESC',
                    ]
                );


        $this->end_controls_section();
        $this->start_controls_section(
            'styling_section',
            [
                'label' => esc_attr__( 'Styling', 'gillion' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

                $this->add_control(
                    'pagination',
                    [
                        'label' => esc_attr__( 'Pagination', 'gillion' ),
                        'description' => esc_attr__( 'Enable or disable load more button. Notice: It will disable multiple other options depending on pagination type (like categories, offset etc)', 'gillion' ),
                        'type' => Controls_Manager::SELECT,
                        'options' => [
                            'disabled' => esc_attr__( 'Disabled', 'gillion' ),
							'pagination' => esc_attr__( 'Pagination', 'gillion' ),
                            'load_more' => esc_attr__( 'Load More Button', 'gillion' ),
                        ],
                        'default' => 'disabled',
                    ]
                );

				$this->add_control(
                    'pagination_align',
                    [
                        'label' => esc_attr__( 'Pagination Alignment', 'gillion' ),
                        'description' => esc_attr__( 'Choose pagination alignment', 'gillion' ),
                        'type' => Controls_Manager::SELECT,
                        'options' => [
                            'left' => esc_attr__( 'Left', 'gillion' ),
							'center' => esc_attr__( 'Center', 'gillion' ),
                            'right' => esc_attr__( 'Right', 'gillion' ),
                        ],
                        'default' => 'center',
						'prefix_class' => 'sh-pagination-',
						'condition' => [
							'pagination' => 'pagination',
						],
                    ]
                );

                $this->add_control(
                    'title',
                    [
                        'label' => esc_attr__( 'Title', 'gillion' ),
                        'description' => esc_attr__( 'Enter blog posts title', 'gillion' ),
                        'type' => Controls_Manager::TEXT,
                        'default' => 'Blog Posts',
                    ]
                );

                $this->add_control(
                    'title_border_color',
                    [
                        'label' => esc_attr__( 'Title Border Color', 'gillion' ),
                        'description' => esc_attr__( 'Choose title border color for section title style - line under title', 'gillion' ),
                        'type' => Controls_Manager::COLOR,
                    ]
                );

                $this->add_control(
                    'post_title_hover_color',
                    [
                        'label' => esc_attr__( 'Post Title Hover Color', 'gillion' ),
                        'description' => esc_attr__( 'Choose title hover color', 'gillion' ),
                        'type' => Controls_Manager::COLOR,
                    ]
                );

                $this->add_control(
                    'lines',
                    [
                        'label' => esc_attr__( 'Hide Post Seperators', 'gillion' ),
                        'description' => esc_attr__( 'Choose to enable or disable post seperator lines', 'gillion' ),
                        'type' => Controls_Manager::SWITCHER,
						'return_value' => 'yes',
                        'default' => 'yes',
                        'label_on' => esc_attr__( 'On', 'gillion' ),
                        'label_off' => esc_attr__( 'Off', 'gillion' ),
                    ]
                );

                $this->add_control(
                    'page_blog_description',
                    [
                        'label' => esc_attr__( 'Blog Posts Description', 'gillion' ),
                        'description' => esc_attr__( '', 'gillion' ),
                        'type' => Controls_Manager::SELECT,
                        'options' => [
                            'default' => esc_attr__( 'Default', 'gillion' ),
                            'off' => esc_attr__( 'Off', 'gillion' ),
                        ],
                        'default' => 'default',
                    ]
                );

            $this->end_controls_section();
	}


	/**
	 * Render the widget output on the frontend.
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$settings = (array)$settings;
		$settings['elementor'] = true;
		vcBlogPosts::_html( $settings );
	}
}
