<?php
namespace ElementorGillionElements\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Core\Schemes\Typography;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Frontend;
use vcBlogPostsCategories;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor - Blog Posts
 */
class Gillion_Blog_Posts_Categories extends Widget_Base {

	/**
	 * Adds scripts
	 */
	public function __construct($data = [], $args = null) {
       parent::__construct($data, $args);
    }

	/**
	 * Retrieve the widget name.
	 */
	public function get_name() {
		return 'gillion-blog-posts-categories';
	}

	/**
	 * Retrieve the widget title.
	 */
	public function get_title() {
		return esc_attr__( 'Blog Posts Categories', 'gillion' );
	}


	/**
	 * Retrieve the widget icon.
	 */
	 public function get_icon() {
 		return 'fas fa-pencil-alt';
 	}


	/**
	 * Retrieve the list of categories the widget belongs to.
	 */
	public function get_categories() {
		return [ 'gillion' ];
	}


	/**
	 * Register the widget controls.
	 */
	protected function register_controls() {
        $this->start_controls_section(
            'section_content',
            [
                'label' => esc_attr__( 'Content', 'gillion' ),
            ]
        );

                $this->add_control(
                    'style',
                    [
                        'label' => esc_attr__( 'Posts Style', 'gillion' ),
                        'description' => esc_attr__( 'Choose slider style', 'gillion' ),
                        'type' => Controls_Manager::SELECT,
                        'options' => [
                            'style1' => esc_attr__( 'Style 1 (grid layout categories posts)', 'gillion' ),
                            'style2' => esc_attr__( 'Style 2 (left slide with right posts scrollbar - large titles)', 'gillion' ),
                            'style2 style4' => esc_attr__( 'Style 3 (left slide with right posts scrollbar - small titles)', 'gillion' ),
                            'style1 sh-categories-style3' => esc_attr__( 'Style 4 (small grid layout categories posts)', 'gillion' ),
                            'style5' => esc_attr__( 'Style 5 (grid layout categories posts)', 'gillion' ),
                        ],
                        'default' => 'style1',

                    ]
                );


                $this->add_control(
                    'image_radious',
                    [
                        'label' => esc_attr__( 'Posts Image Radius', 'gillion' ),
                        'description' => esc_attr__( 'Choose small posts image radius', 'gillion' ),
                        'type' => Controls_Manager::SELECT,
                        'options' => [
                            '8px' => esc_attr__( '8px (standard)', 'gillion' ),
                            '100%' => esc_attr__( '100%  (full circle)', 'gillion' ),
                        ],
                        'default' => '8px',
                        'condition' => [
                            'style' => [ 'style2' ]
                        ]

                    ]
                );


                $this->add_control(
                    'limit',
                    [
                        'label' => esc_attr__( 'Posts Limit', 'gillion' ),
                        'description' => esc_attr__( 'Choose posts limit', 'gillion' ),
                        'type' => Controls_Manager::TEXT,

                        'default' => '3',

                    ]
                );


                $this->add_control(
                    'categories',
                    [
                        'label' => esc_attr__( 'Show Only Specific Categories', 'gillion' ),
                        'description' => esc_attr__( 'Enter categories by names to narrow output (Note: only listed categories will be displayed, divide categories with linebreak (Enter)). By default will get most popular categories', 'gillion' ),
                        'type' => Controls_Manager::TEXTAREA,

                    ]
                );


                $this->add_control(
                    'order',
                    [
                        'label' => esc_attr__( 'Order', 'gillion' ),
                        'description' => esc_attr__( '', 'gillion' ),
                        'type' => Controls_Manager::SELECT,
                        'options' => [
                            'asc' => esc_attr__( 'Ascending', 'gillion' ),
                            'desc' => esc_attr__( 'Descending', 'gillion' ),
                        ],
                        'default' => 'asc',

                    ]
                );



        $this->end_controls_section();
        $this->start_controls_section(
            'styling_section',
            [
                'label' => esc_attr__( 'Styling', 'gillion' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

                $this->add_control(
                    'title',
                    [
                        'label' => esc_attr__( 'Title', 'gillion' ),
                        'description' => esc_attr__( 'Enter categories title (works for style 2, style 3, style 4)', 'gillion' ),
                        'type' => Controls_Manager::TEXT,

                        'default' => 'Categories',
                        'condition' => [
                            'style' => [ 'style2' , 'style2 style4' , 'style1 sh-categories-style3' , 'style5' ]
                        ]

                    ]
                );


                $this->add_control(
                    'title_border_color',
                    [
                        'label' => esc_attr__( 'Title Border Color', 'gillion' ),
                        'description' => esc_attr__( 'Choose title border color for section title style - line under title', 'gillion' ),
                        'type' => Controls_Manager::COLOR,
                                        'condition' => [
                            'style' => [ 'style2' , 'style2 style4' , 'style1 sh-categories-style3' , 'style5' ]
                        ]

                    ]
                );


                $this->add_control(
                    'post_title_hover_color',
                    [
                        'label' => esc_attr__( 'Post Title Hover Color', 'gillion' ),
                        'description' => esc_attr__( 'Choose title hover color', 'gillion' ),
                        'type' => Controls_Manager::COLOR,

                    ]
                );

            $this->end_controls_section();
	}


	/**
	 * Render the widget output on the frontend.
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$settings = (array)$settings;
		$settings['elementor'] = true;
		vcBlogPostsCategories::_html( $settings );
	}
}
