<?php
namespace ElementorGillionElements\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Core\Schemes\Typography;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Frontend;
use vcBlogPostsFancy;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor - Blog Posts
 */
class Gillion_Blog_Posts extends Widget_Base {

	/**
	 * Adds scripts
	 */
	public function __construct($data = [], $args = null) {
       parent::__construct($data, $args);
    }

	/**
	 * Retrieve the widget name.
	 */
	public function get_name() {
		return 'gillion-blog-posts';
	}

	/**
	 * Retrieve the widget title.
	 */
	public function get_title() {
		return esc_attr__( 'Blog Posts', 'gillion' );
	}


	/**
	 * Retrieve the widget icon.
	 */
	 public function get_icon() {
 		return 'fas fa-pencil-alt';
 	}


	/**
	 * Retrieve the list of categories the widget belongs to.
	 */
	public function get_categories() {
		return [ 'gillion' ];
	}


	/**
	 * Register the widget controls.
	 */
	protected function register_controls() {
		$this->start_controls_section(
		    'section_content',
		    [
		        'label' => esc_attr__( 'Content', 'gillion' ),
		    ]
		);

		        $this->add_control(
		            'style',
		            [
		                'label' => esc_attr__( 'Posts Style', 'gillion' ),
		                'description' => esc_attr__( 'Choose posts style', 'gillion' ),
		                'type' => Controls_Manager::SELECT,
		                'options' => [
		                    'cover' => esc_attr__( 'Cover', 'gillion' ),
		                    'coverbig' => esc_attr__( 'Cover Big', 'gillion' ),
		                    'mini1' => esc_attr__( 'Mini 1', 'gillion' ),
		                    'mini2' => esc_attr__( 'Mini 2', 'gillion' ),
		                    'fancy1' => esc_attr__( 'Fancy 1', 'gillion' ),
		                    'fancy2' => esc_attr__( 'Fancy 2', 'gillion' ),
		                    'fancy3' => esc_attr__( 'Fancy 3', 'gillion' ),
		                    'round' => esc_attr__( 'Round Simple', 'gillion' ),
		                    'card' => esc_attr__( 'Card Style', 'gillion' ),
		                ],
		                'default' => 'cover',

		            ]
		        );


		        $this->add_control(
		            'columns',
		            [
		                'label' => esc_attr__( 'Posts Columns', 'gillion' ),
		                'description' => esc_attr__( 'Choose post column count', 'gillion' ),
		                'type' => Controls_Manager::SELECT,
		                'options' => [
		                    'columns3' => esc_attr__( 'Columns 3', 'gillion' ),
		                    'columns2' => esc_attr__( 'Columns 2', 'gillion' ),
		                ],
		                'default' => 'columns3',
		                'condition' => [
		                    'style' => [ 'cover' ]
		                ]

		            ]
		        );


		        $this->add_control(
		            'columns2',
		            [
		                'label' => esc_attr__( 'Posts Columns', 'gillion' ),
		                'description' => esc_attr__( 'Choose post column count', 'gillion' ),
		                'type' => Controls_Manager::SELECT,
		                'options' => [
		                    'columns4' => esc_attr__( 'Columns 4', 'gillion' ),
		                    'columns3' => esc_attr__( 'Columns 3', 'gillion' ),
		                    'columns2' => esc_attr__( 'Columns 2', 'gillion' ),
		                ],
		                'default' => 'columns4',
		                'condition' => [
		                    'style' => [ 'mini1' ]
		                ]

		            ]
		        );


		        $this->add_control(
		            'columns3',
		            [
		                'label' => esc_attr__( 'Posts Columns', 'gillion' ),
		                'description' => esc_attr__( 'Choose post column count', 'gillion' ),
		                'type' => Controls_Manager::SELECT,
		                'options' => [
		                    'columns4' => esc_attr__( 'Columns 4', 'gillion' ),
		                    'columns3' => esc_attr__( 'Columns 3', 'gillion' ),
		                ],
		                'default' => 'columns4',
		                'condition' => [
		                    'style' => [ 'mini2' ]
		                ]

		            ]
		        );


		        $this->add_control(
		            'alignment',
		            [
		                'label' => esc_attr__( 'Posts Content Alignment', 'gillion' ),
		                'description' => esc_attr__( 'Choose posts content alignment (works for some of the post styles)', 'gillion' ),
		                'type' => Controls_Manager::SELECT,
		                'options' => [
		                    'left' => esc_attr__( 'Left', 'gillion' ),
		                    'center' => esc_attr__( 'Center', 'gillion' ),
		                ],
		                'default' => 'left',
		                'condition' => [
		                    'style' => [ 'cover' , 'coverbig' ]
		                ]

		            ]
		        );


		        $this->add_control(
		            'limit',
		            [
		                'label' => esc_attr__( 'Posts Limit', 'gillion' ),
		                'description' => esc_attr__( 'Choose posts limit', 'gillion' ),
		                'type' => Controls_Manager::TEXT,

		                'default' => '3',

		            ]
		        );


		        $this->add_control(
		            'offset',
		            [
		                'label' => esc_attr__( 'Posts Offset', 'gillion' ),
		                'description' => esc_attr__( 'Enter posts offset number (will be disabled when using specific posts only)', 'gillion' ),
		                'type' => Controls_Manager::TEXT,

		            ]
		        );


		        $this->add_control(
		            'posts',
		            [
		                'label' => esc_attr__( 'Show Only Specific Posts', 'gillion' ),
		                'description' => esc_attr__( 'Enter post IDs with comma, like: 1,2,3,4,5', 'gillion' ),
		                'type' => Controls_Manager::TEXT,

		            ]
		        );


		        $this->add_control(
		            'categories',
		            [
		                'label' => esc_attr__( 'Show Only Specific Categories', 'gillion' ),
		                'description' => esc_attr__( 'Enter categories slugs to narrow output (Note: only listed categories will be displayed, divide categories with linebreak (Enter)).', 'gillion' ),
		                'type' => Controls_Manager::TEXTAREA,

		            ]
		        );


		        $this->add_control(
		            'tags',
		            [
		                'label' => esc_attr__( 'Show Only Specific Tags', 'gillion' ),
		                'description' => esc_attr__( 'Enter tags slugs to narrow output (Note: only listed tags will be displayed, divide categories with linebreak (Enter)).', 'gillion' ),
		                'type' => Controls_Manager::TEXTAREA,

		            ]
		        );


		        $this->add_control(
		            'order_by',
		            [
		                'label' => esc_attr__( 'Order By', 'gillion' ),
		                'description' => esc_attr__( '', 'gillion' ),
		                'type' => Controls_Manager::SELECT,
		                'options' => [
		                    'date' => esc_attr__( 'Date', 'gillion' ),
		                    'name' => esc_attr__( 'Name', 'gillion' ),
		                    'author' => esc_attr__( 'Author', 'gillion' ),
		                    'rand' => esc_attr__( 'Random', 'gillion' ),
		                    'comment_count' => esc_attr__( 'Comment Count', 'gillion' ),
		                ],
		                'default' => 'date',

		            ]
		        );


		        $this->add_control(
		            'order',
		            [
		                'label' => esc_attr__( 'Order', 'gillion' ),
		                'description' => esc_attr__( '', 'gillion' ),
		                'type' => Controls_Manager::SELECT,
		                'options' => [
		                    'desc' => esc_attr__( 'Descending', 'gillion' ),
		                    'asc' => esc_attr__( 'Ascending', 'gillion' ),
		                ],
		                'default' => 'desc',

		            ]
		        );



		$this->end_controls_section();
		$this->start_controls_section(
		    'styling_section',
		    [
		        'label' => esc_attr__( 'Styling', 'gillion' ),
		        'tab' => Controls_Manager::TAB_STYLE,
		    ]
		);

		        $this->add_control(
		            'carousel',
		            [
		                'label' => esc_attr__( 'Carousel', 'gillion' ),
		                'description' => esc_attr__( '', 'gillion' ),
		                'type' => Controls_Manager::SELECT,
		                'options' => [
		                    'disabled' => esc_attr__( 'Disabled', 'gillion' ),
		                    'sides' => esc_attr__( 'Enabled with arrows in sides', 'gillion' ),
		                    'title' => esc_attr__( 'Enabled with arrows in title', 'gillion' ),
		                    'withoutarrows' => esc_attr__( 'Enabled without arrows', 'gillion' ),
		                ],
		                'default' => 'disabled',
		                'condition' => [
		                    'style' => [ 'cover' , 'coverbig' , 'mini1' , 'mini2' ]
		                ]

		            ]
		        );


		        $this->add_control(
		            'autoplay',
		            [
		                'label' => esc_attr__( 'Autoplay', 'gillion' ),
		                'description' => esc_attr__( 'Choose to enable or disable slider autoplay (if slider is enabled)', 'gillion' ),
		                'type' => Controls_Manager::SWITCHER,
						'return_value' => 'yes',
		                'default' => 'yes',
		                'label_on' => esc_attr__( 'On', 'gillion' ),
		                'label_off' => esc_attr__( 'Off', 'gillion' ),
		                'condition' => [
		                    'carousel' => [ 'sides' , 'title' , 'withoutarrows' ]
		                ]

		            ]
		        );


		        $this->add_control(
		            'autoplay_speed',
		            [
		                'label' => esc_attr__( 'Autoplay Speed (s)', 'gillion' ),
		                'description' => esc_attr__( 'Choose autoplay speed (1-10 seconds interval)', 'gillion' ),
		                'type' => Controls_Manager::TEXT,

		                'default' => '6',
		                'condition' => [
		                    'carousel' => [ 'sides' , 'title' , 'withoutarrows' ]
		                ]

		            ]
		        );


		        $this->add_control(
		            'title',
		            [
		                'label' => esc_attr__( 'Title', 'gillion' ),
		                'description' => esc_attr__( 'Enter title', 'gillion' ),
		                'type' => Controls_Manager::TEXT,

		            ]
		        );


		        $this->add_control(
		            'title_border_color',
		            [
		                'label' => esc_attr__( 'Title Border Color', 'gillion' ),
		                'description' => esc_attr__( 'Choose title border color for section title style - line under title', 'gillion' ),
		                'type' => Controls_Manager::COLOR,

		            ]
		        );


		        $this->add_control(
		            'post_title_hover_color',
		            [
		                'label' => esc_attr__( 'Post Title Hover Color', 'gillion' ),
		                'description' => esc_attr__( 'Choose title hover color', 'gillion' ),
		                'type' => Controls_Manager::COLOR,

		            ]
		        );


		        $this->add_control(
		            'disable_categories',
		            [
		                'label' => esc_attr__( 'Disable Categories', 'gillion' ),
		                'description' => esc_attr__( 'Check to disable categories', 'gillion' ),
		                'type' => Controls_Manager::SWITCHER,
						'return_value' => 'yes',
		                'default' => 'yes',
		                'label_on' => esc_attr__( 'On', 'gillion' ),
		                'label_off' => esc_attr__( 'Off', 'gillion' ),

		            ]
		        );

		    $this->end_controls_section();
	}


	/**
	 * Render the widget output on the frontend.
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$settings = (array)$settings;
		$settings['elementor'] = true;
		vcBlogPostsFancy::_html( $settings );
	}
}
