<?php
namespace ElementorGillionElements\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Core\Schemes\Typography;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Frontend;
use vcBlogSlider;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor - Blog Posts
 */
class Gillion_Blog_Slider extends Widget_Base {

	/**
	 * Adds scripts
	 */
	public function __construct($data = [], $args = null) {
       parent::__construct($data, $args);
    }

	/**
	 * Retrieve the widget name.
	 */
	public function get_name() {
		return 'gillion-blog-slider';
	}

	/**
	 * Retrieve the widget title.
	 */
	public function get_title() {
		return esc_attr__( 'Blog Slider', 'gillion' );
	}


	/**
	 * Retrieve the widget icon.
	 */
	public function get_icon() {
		return 'fas fa-layer-group';
	}


	/**
	 * Retrieve the list of categories the widget belongs to.
	 */
	public function get_categories() {
		return [ 'gillion' ];
	}


	/**
	 * Register the widget controls.
	 */
	protected function register_controls() {
        $this->start_controls_section(
            'section_content',
            [
                'label' => esc_attr__( 'Content', 'gillion' ),
            ]
        );

                $this->add_control(
                    'style',
                    [
                        'label' => esc_attr__( 'Post Style', 'gillion' ),
                        'description' => esc_attr__( 'Choose slider style', 'gillion' ),
                        'type' => Controls_Manager::SELECT,
                        'options' => [
                            'style1' => esc_attr__( 'Style 1 (single slide)', 'gillion' ),
                            'style2' => esc_attr__( 'Style 2 (carousel)', 'gillion' ),
                            'style3' => esc_attr__( 'Style 3 (single slide without arrows)', 'gillion' ),
                            'style4' => esc_attr__( 'Style 4 (single slide with side list)', 'gillion' ),
                            'style5' => esc_attr__( 'Style 5 (grid slide with 3 posts)', 'gillion' ),
                            'style6' => esc_attr__( 'Style 6 (single slide without arrows in center)', 'gillion' ),
                            'style7' => esc_attr__( 'Style 7 (single slide with side content)', 'gillion' ),
                            'style8' => esc_attr__( 'Style 8 (grid slide with 4 posts)', 'gillion' ),
                            'style9' => esc_attr__( 'Style 9 (mosaic slide with 4 posts)', 'gillion' ),
                            'style2 style10' => esc_attr__( 'Style 10 (carousel - centered)', 'gillion' ),
                            'style11' => esc_attr__( 'Style 11 (minimalistic)', 'gillion' ),
                            'style12' => esc_attr__( 'Style 12 (mosaic slide with 5 posts)', 'gillion' ),
                        ],
                        'default' => 'style1',

                    ]
                );


                $this->add_control(
                    'limit',
                    [
                        'label' => esc_attr__( 'Posts Limit', 'gillion' ),
                        'description' => esc_attr__( 'Choose posts limit', 'gillion' ),
                        'type' => Controls_Manager::TEXT,

                        'default' => '3',

                    ]
                );


                $this->add_control(
                    'exclude_latest_posts',
                    [
                        'label' => esc_attr__( 'Exclude Latest Posts', 'gillion' ),
                        'description' => esc_attr__( 'Choose how many latest posts will be excluded. Notice: will work only if "Show Only Specific Posts" or "Categories" option is not used', 'gillion' ),
                        'type' => Controls_Manager::TEXT,

                    ]
                );


                $this->add_control(
                    'posts',
                    [
                        'label' => esc_attr__( 'Show Only Specific Posts', 'gillion' ),
                        'description' => esc_attr__( 'Enter post IDs with comma, like: 1,2,3,4,5. It will overwrite categories option', 'gillion' ),
                        'type' => Controls_Manager::TEXT,

                    ]
                );


                $this->add_control(
                    'categories',
                    [
                        'label' => esc_attr__( 'Show Only Specific Categories', 'gillion' ),
                        'description' => esc_attr__( 'Enter categories by names to narrow output (Note: only listed categories will be displayed, divide categories with linebreak (Enter)).', 'gillion' ),
                        'type' => Controls_Manager::TEXTAREA,

                    ]
                );



        $this->end_controls_section();
        $this->start_controls_section(
            'styling_section',
            [
                'label' => esc_attr__( 'Styling', 'gillion' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

                $this->add_control(
                    'autoplay',
                    [
                        'label' => esc_attr__( 'Autoplay', 'gillion' ),
                        'description' => esc_attr__( 'Choose to enable or disable slider autoplay', 'gillion' ),
                        'type' => Controls_Manager::SWITCHER,
						'return_value' => 'yes',
                        'default' => 'yes',
                        'label_on' => esc_attr__( 'On', 'gillion' ),
                        'label_off' => esc_attr__( 'Off', 'gillion' ),

                    ]
                );


                $this->add_control(
                    'autoplay_speed',
                    [
                        'label' => esc_attr__( 'Autoplay Speed (s)', 'gillion' ),
                        'description' => esc_attr__( 'Choose Autoplay Speed (1-10 seconds interval)', 'gillion' ),
                        'type' => Controls_Manager::TEXT,

                        'default' => '6',

                    ]
                );


                $this->add_control(
                    'meta',
                    [
                        'label' => esc_attr__( 'Information Fields', 'gillion' ),
                        'description' => esc_attr__( 'Choose slider information fields', 'gillion' ),
                        'type' => Controls_Manager::SELECT,
                        'options' => [
                            '51' => esc_attr__( 'Author, Date + Comments + Read time', 'gillion' ),
                            '50' => esc_attr__( 'Author, Date + Comments + Read time + Page Views', 'gillion' ),
                            '52' => esc_attr__( 'Author, Date + Comments + Page Views', 'gillion' ),
                            '53' => esc_attr__( 'Author, Date + Comments', 'gillion' ),
                            '54' => esc_attr__( 'Author, Date', 'gillion' ),
                            '55' => esc_attr__( 'Author (without image), Date', 'gillion' ),
                            '56' => esc_attr__( 'Author (without image), Date + Comments', 'gillion' ),
                            'none' => esc_attr__( 'None', 'gillion' ),
                        ],
                        'default' => '51',

                    ]
                );


                $this->add_control(
                    'dots',
                    [
                        'label' => esc_attr__( 'Slider Dots', 'gillion' ),
                        'description' => esc_attr__( 'Choose to enable or disable slider dots', 'gillion' ),
                        'type' => Controls_Manager::SWITCHER,
						'return_value' => 'yes',
                        'default' => 'yes',
                        'label_on' => esc_attr__( 'On', 'gillion' ),
                        'label_off' => esc_attr__( 'Off', 'gillion' ),
                    ]
                );


                $this->add_control(
                    'uppercase',
                    [
                        'label' => esc_attr__( 'Uppercase Title', 'gillion' ),
                        'description' => esc_attr__( 'Choose to enable or disable uppercase title', 'gillion' ),
                        'type' => Controls_Manager::SWITCHER,
						'return_value' => 'yes',
                        'default' => 'yes',
                        'label_on' => esc_attr__( 'On', 'gillion' ),
                        'label_off' => esc_attr__( 'Off', 'gillion' ),

                    ]
                );

            $this->end_controls_section();
	}


	/**
	 * Render the widget output on the frontend.
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$settings = (array)$settings;
		$settings['elementor'] = true;
		vcBlogSlider::_html( $settings );
	}
}
