<?php
namespace ElementorGillionElements\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Core\Schemes\Typography;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Frontend;
use vcBlogTextSlider;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor - Blog Posts
 */
class Gillion_Blog_Text_Slider extends Widget_Base {

	/**
	 * Adds scripts
	 */
	public function __construct($data = [], $args = null) {
       parent::__construct($data, $args);
    }

	/**
	 * Retrieve the widget name.
	 */
	public function get_name() {
		return 'gillion-blog-text-slider';
	}

	/**
	 * Retrieve the widget title.
	 */
	public function get_title() {
		return esc_attr__( 'Blog Text Slider', 'gillion' );
	}


	/**
	 * Retrieve the widget icon.
	 */
	public function get_icon() {
		return 'fas fa-text-width';
	}


	/**
	 * Retrieve the list of categories the widget belongs to.
	 */
	public function get_categories() {
		return [ 'gillion' ];
	}


	/**
	 * Register the widget controls.
	 */
	protected function register_controls() {
        $this->start_controls_section(
            'section_content',
            [
                'label' => esc_attr__( 'Content', 'gillion' ),
            ]
        );

                $this->add_control(
                    'limit',
                    [
                        'label' => esc_attr__( 'Posts Limit', 'gillion' ),
                        'description' => esc_attr__( 'Choose posts limit', 'gillion' ),
                        'type' => Controls_Manager::TEXT,
                        'default' => '4',
                    ]
                );


                $this->add_control(
                    'posts',
                    [
                        'label' => esc_attr__( 'Show Only Specific Posts', 'gillion' ),
                        'description' => esc_attr__( 'Enter post IDs with comma, like: 1,2,3,4,5', 'gillion' ),
                        'type' => Controls_Manager::TEXT,

                    ]
                );


                $this->add_control(
                    'categories',
                    [
                        'label' => esc_attr__( 'Show Only Specific Categories', 'gillion' ),
                        'description' => esc_attr__( 'Enter categories by names to narrow output (Note: only listed categories will be displayed, divide categories with linebreak (Enter)).', 'gillion' ),
                        'type' => Controls_Manager::TEXTAREA,

                    ]
                );


                $this->add_control(
                    'order_by',
                    [
                        'label' => esc_attr__( 'Order By', 'gillion' ),
                        'description' => esc_attr__( '', 'gillion' ),
                        'type' => Controls_Manager::SELECT,
                        'options' => [
                            'date' => esc_attr__( 'Date', 'gillion' ),
                            'name' => esc_attr__( 'Name', 'gillion' ),
                            'author' => esc_attr__( 'Author', 'gillion' ),
                            'rand' => esc_attr__( 'Random', 'gillion' ),
                            'comment_count' => esc_attr__( 'Comment Count', 'gillion' ),
                        ],
                        'default' => 'date',
                    ]
                );


                $this->add_control(
                    'order',
                    [
                        'label' => esc_attr__( 'Order', 'gillion' ),
                        'description' => esc_attr__( '', 'gillion' ),
                        'type' => Controls_Manager::SELECT,
                        'options' => [
                            'asc' => esc_attr__( 'Ascending', 'gillion' ),
                            'desc' => esc_attr__( 'Descending', 'gillion' ),
                        ],
                        'default' => 'asc',
                    ]
                );


                $this->add_control(
                    'title',
                    [
                        'label' => esc_attr__( 'Title', 'gillion' ),
                        'description' => esc_attr__( 'Enter title', 'gillion' ),
                        'type' => Controls_Manager::TEXT,
                        'default' => 'Trending Articles',
                    ]
                );



        $this->end_controls_section();
        $this->start_controls_section(
            'styling_section',
            [
                'label' => esc_attr__( 'Styling', 'gillion' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

                $this->add_control(
                    'style',
                    [
                        'label' => esc_attr__( 'Style', 'gillion' ),
                        'description' => esc_attr__( '', 'gillion' ),
                        'type' => Controls_Manager::SELECT,
                        'options' => [
                            'style1' => esc_attr__( 'Style 1', 'gillion' ),
                            'style2' => esc_attr__( 'Style 2', 'gillion' ),
                            'style3' => esc_attr__( 'Style 3', 'gillion' ),
                            'style4' => esc_attr__( 'Style 4', 'gillion' ),
                            'style5' => esc_attr__( 'Style 5', 'gillion' ),
                            'style6' => esc_attr__( 'Style 6 (with load more button instead of next/prev arrows)', 'gillion' ),
                        ],
                        'default' => 'style1',
                    ]
                );


                $this->add_control(
                    'color',
                    [
                        'label' => esc_attr__( 'Color', 'gillion' ),
                        'description' => esc_attr__( '', 'gillion' ),
                        'type' => Controls_Manager::COLOR,
                    ]
                );


                $this->add_control(
                    'uppercase',
                    [
                        'label' => esc_attr__( 'Uppercase Post Titles', 'gillion' ),
                        'description' => esc_attr__( 'Choose to enable or disable uppercase post titles', 'gillion' ),
                        'type' => Controls_Manager::SWITCHER,
						'return_value' => '1',
                        'default' => '1',
                        'label_on' => esc_attr__( 'On', 'gillion' ),
                        'label_off' => esc_attr__( 'Off', 'gillion' ),
                    ]
                );


        $this->end_controls_section();
	}


	/**
	 * Render the widget output on the frontend.
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$settings = (array)$settings;
		$settings['elementor'] = true;
		vcBlogTextSlider::_html( $settings );
	}
}
