<?php
namespace ElementorGillionElements\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Core\Schemes\Typography;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Frontend;
use vcj_footer_widgets_title;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor - Blog Posts
 */
class Gillion_Footer_Widgets_Title extends Widget_Base {

	/**
	 * Adds scripts
	 */
	public function __construct($data = [], $args = null) {
       parent::__construct($data, $args);
    }

	/**
	 * Retrieve the widget name.
	 */
	public function get_name() {
		return 'gillion-footer-widgets-title';
	}

	/**
	 * Retrieve the widget title.
	 */
	public function get_title() {
		return esc_attr__( 'Widget Heading', 'gillion' );
	}


	/**
	 * Retrieve the widget icon.
	 */
	public function get_icon() {
		return 'fas fa-heading';
	}


	/**
	 * Retrieve the list of categories the widget belongs to.
	 */
	public function get_categories() {
		return [ 'gillion' ];
	}


	/**
	 * Register the widget controls.
	 */
	protected function register_controls() {
        $this->start_controls_section(
            'section_content',
            [
                'label' => esc_attr__( 'Content', 'gillion' ),
            ]
        );

                $this->add_control(
                    'title',
                    [
                        'label' => esc_attr__( 'Title', 'gillion' ),
                        'description' => esc_attr__( 'Enter title', 'gillion' ),
                        'type' => Controls_Manager::TEXT,

                    ]
                );


                $this->add_control(
                    'preset',
                    [
                        'label' => esc_attr__( 'Color Preset', 'gillion' ),
                        'description' => esc_attr__( 'Choose color preset, that can be overwritten by color options', 'gillion' ),
                        'type' => Controls_Manager::SELECT,
                        'options' => [
                            'dark' => esc_attr__( 'Dark Text', 'gillion' ),
                            'light' => esc_attr__( 'Light Text', 'gillion' ),
                        ],
                        'default' => 'dark',

                    ]
                );


                $this->add_control(
                    'heading_size',
                    [
                        'label' => esc_attr__( 'Heading Font Size', 'gillion' ),
                        'description' => esc_attr__( 'Enter heading size (Note: CSS measurement units allowed).', 'gillion' ),
                        'type' => Controls_Manager::TEXT,

                    ]
                );


                $this->add_control(
                    'line_height',
                    [
                        'label' => esc_attr__( 'Line Height', 'gillion' ),
                        'description' => esc_attr__( 'Enter line height (Note: CSS measurement units allowed).', 'gillion' ),
                        'type' => Controls_Manager::TEXT,

                    ]
                );



        $this->end_controls_section();$this->start_controls_section(
            'styling_section',
            [
                'label' => esc_attr__( 'Styling', 'gillion' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

                $this->add_control(
                    'heading_color',
                    [
                        'label' => esc_attr__( 'Heading Color', 'gillion' ),
                        'description' => esc_attr__( 'Select heading color', 'gillion' ),
                        'type' => Controls_Manager::COLOR,

                    ]
                );


                $this->add_control(
                    'border_color',
                    [
                        'label' => esc_attr__( 'Border Color', 'gillion' ),
                        'description' => esc_attr__( 'Select border color', 'gillion' ),
                        'type' => Controls_Manager::COLOR,

                    ]
                );


                $this->add_control(
                    'border_color2',
                    [
                        'label' => esc_attr__( 'Border Color 2', 'gillion' ),
                        'description' => esc_attr__( 'Select border color 2', 'gillion' ),
                        'type' => Controls_Manager::COLOR,

                    ]
                );


            $this->end_controls_section();
	}


	/**
	 * Render the widget output on the frontend.
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$settings = (array)$settings;
		$settings['elementor'] = true;
		vcj_footer_widgets_title::_html( $settings );
	}
}
