<?php
namespace ElementorGillionElements\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Core\Schemes\Typography;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Frontend;
use vcj_footer_widgets;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor - Blog Posts
 */
class Gillion_Footer_Widgets extends Widget_Base {

	/**
	 * Adds scripts
	 */
	public function __construct($data = [], $args = null) {
       parent::__construct($data, $args);
    }

	/**
	 * Retrieve the widget name.
	 */
	public function get_name() {
		return 'gillion-footer-widgets';
	}

	/**
	 * Retrieve the widget title.
	 */
	public function get_title() {
		return esc_attr__( 'Widgets', 'gillion' );
	}


	/**
	 * Retrieve the widget icon.
	 */
	public function get_icon() {
		return 'fas fa-align-justify';
	}


	/**
	 * Retrieve the list of categories the widget belongs to.
	 */
	public function get_categories() {
		return [ 'gillion' ];
	}


	/**
	 * Register the widget controls.
	 */
	protected function register_controls() {
        $this->start_controls_section(
            'section_content',
            [
                'label' => esc_attr__( 'Content', 'gillion' ),
            ]
        );

                $this->add_control(
                    'alignment',
                    [
                        'label' => esc_attr__( 'Widgets Alignment', 'gillion' ),
                        'description' => esc_attr__( 'Choose widgets alignment', 'gillion' ),
                        'type' => Controls_Manager::SELECT,
                        'options' => [
                            'vertical' => esc_attr__( 'Vertical (below each other)', 'gillion' ),
                            'horizontal' => esc_attr__( 'Horizontal (side by side)', 'gillion' ),
                        ],
                        'default' => 'vertical',

                    ]
                );


                $this->add_control(
                    'columns',
                    [
                        'label' => esc_attr__( 'Columns', 'gillion' ),
                        'description' => esc_attr__( 'Choose widgets columns count (for horizontal algnment)', 'gillion' ),
                        'type' => Controls_Manager::SELECT,
                        'options' => [
                            '1' => esc_attr__( '1 Columns', 'gillion' ),
                            '2' => esc_attr__( '2 Columns', 'gillion' ),
                            '3' => esc_attr__( '3 Columns', 'gillion' ),
                            '4' => esc_attr__( '4 Columns', 'gillion' ),
                            '5' => esc_attr__( '5 Columns', 'gillion' ),
                        ],
                        'default' => '1',

                    ]
                );


                $this->add_control(
                    'preset',
                    [
                        'label' => esc_attr__( 'Color Preset', 'gillion' ),
                        'description' => esc_attr__( 'Choose color preset, that can be overwritten by color options', 'gillion' ),
                        'type' => Controls_Manager::SELECT,
                        'options' => [
                            'dark' => esc_attr__( 'Dark Text', 'gillion' ),
                            'light' => esc_attr__( 'Light Text', 'gillion' ),
                        ],
                        'default' => 'dark',

                    ]
                );


                $this->add_control(
                    'text_size',
                    [
                        'label' => esc_attr__( 'Text Font Size', 'gillion' ),
                        'description' => esc_attr__( 'Enter text font size (Note: CSS measurement units allowed).', 'gillion' ),
                        'type' => Controls_Manager::TEXT,

                    ]
                );


                $this->add_control(
                    'heading_size',
                    [
                        'label' => esc_attr__( 'Heading Font Size', 'gillion' ),
                        'description' => esc_attr__( 'Enter heading size (Note: CSS measurement units allowed).', 'gillion' ),
                        'type' => Controls_Manager::TEXT,

                    ]
                );


                $this->add_control(
                    'line_height',
                    [
                        'label' => esc_attr__( 'Line Height', 'gillion' ),
                        'description' => esc_attr__( 'Enter line height (Note: CSS measurement units allowed).', 'gillion' ),
                        'type' => Controls_Manager::TEXT,

                    ]
                );


                $this->add_control(
                    'source',
                    [
                        'label' => esc_attr__( 'Widget Source', 'gillion' ),
                        'description' => 'Modify widgets <a href="'.admin_url( '/widgets.php' ).'" target="_blank">here</a>. If necessary, you can choose other widget source than footer widgets',
                        'type' => Controls_Manager::SELECT,
                        'options' => [
                            'footer-widgets1' => esc_attr__( 'Footer 1 Widgets', 'gillion' ),
                            'footer-widgets2' => esc_attr__( 'Footer 2 Widgets', 'gillion' ),
                            'footer-widgets3' => esc_attr__( 'Footer 3 Widgets', 'gillion' ),
                            'blog-widgets' => esc_attr__( 'Blog Widgets', 'gillion' ),
                            'page-widgets' => esc_attr__( 'Page Widgets', 'gillion' ),
                            'woocommerce-widgets' => esc_attr__( 'Shop Widgets', 'gillion' ),
                            'vc-widgets' => esc_attr__( 'WPbakery Page Builder Widgets', 'gillion' ),
                            '404-widgets' => esc_attr__( '404 Widgets', 'gillion' ),
                            'side-widgets' => esc_attr__( 'Side Widgets', 'gillion' ),
                        ],
                        'default' => 'footer-widgets1',

                    ]
                );



        $this->end_controls_section();$this->start_controls_section(
            'styling_section',
            [
                'label' => esc_attr__( 'Styling', 'gillion' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

                $this->add_control(
                    'heading_color',
                    [
                        'label' => esc_attr__( 'Heading Color', 'gillion' ),
                        'description' => esc_attr__( 'Select heading color', 'gillion' ),
                        'type' => Controls_Manager::COLOR,

                    ]
                );


                $this->add_control(
                    'text_color',
                    [
                        'label' => esc_attr__( 'Text Color', 'gillion' ),
                        'description' => esc_attr__( 'Select text color', 'gillion' ),
                        'type' => Controls_Manager::COLOR,

                    ]
                );


                $this->add_control(
                    'link_color',
                    [
                        'label' => esc_attr__( 'Link Color', 'gillion' ),
                        'description' => esc_attr__( 'Select link color', 'gillion' ),
                        'type' => Controls_Manager::COLOR,

                    ]
                );


                $this->add_control(
                    'link_hover_color',
                    [
                        'label' => esc_attr__( 'Link Hover Color', 'gillion' ),
                        'description' => esc_attr__( 'Select link hover color', 'gillion' ),
                        'type' => Controls_Manager::COLOR,

                    ]
                );


                $this->add_control(
                    'icon_color',
                    [
                        'label' => esc_attr__( 'Icon Color', 'gillion' ),
                        'description' => esc_attr__( 'Select icon color', 'gillion' ),
                        'type' => Controls_Manager::COLOR,

                    ]
                );


                $this->add_control(
                    'border_color',
                    [
                        'label' => esc_attr__( 'Border Color', 'gillion' ),
                        'description' => esc_attr__( 'Select border color', 'gillion' ),
                        'type' => Controls_Manager::COLOR,

                    ]
                );


                $this->add_control(
                    'border_color2',
                    [
                        'label' => esc_attr__( 'Border Color 2', 'gillion' ),
                        'description' => esc_attr__( 'Select border color 2', 'gillion' ),
                        'type' => Controls_Manager::COLOR,

                    ]
                );


        $this->end_controls_section();
	}


	/**
	 * Render the widget output on the frontend.
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$settings = (array)$settings;
		$settings['elementor'] = true;
		vcj_footer_widgets::_html( $settings );
	}
}
