<?php
namespace ElementorGillionElements\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Core\Schemes\Typography;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Frontend;
use vcImageGallery;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor - Blog Posts
 */
class Gillion_Image_Gallery extends Widget_Base {

	/**
	 * Adds scripts
	 */
	public function __construct($data = [], $args = null) {
       parent::__construct($data, $args);
    }

	/**
	 * Retrieve the widget name.
	 */
	public function get_name() {
		return 'gillion-image-gallery';
	}

	/**
	 * Retrieve the widget title.
	 */
	public function get_title() {
		return esc_attr__( 'Image Gallery', 'gillion' );
	}


	/**
	 * Retrieve the widget icon.
	 */
	public function get_icon() {
		return 'fas fa-images';
	}


	/**
	 * Retrieve the list of categories the widget belongs to.
	 */
	public function get_categories() {
		return [ 'gillion' ];
	}


	/**
	 * Register the widget controls.
	 */
	protected function register_controls() {
        $this->start_controls_section(
            'section_content',
            [
                'label' => esc_attr__( 'Content', 'gillion' ),
            ]
        );


            $this->add_control(
                'images',
                [
                    'label' => esc_attr__( 'Images', 'gillion' ),
                    'description' => esc_attr__( 'Choose images', 'gillion' ),
                    'type' => \Elementor\Controls_Manager::GALLERY,
                ]
            );

            $this->add_control(
                'images_size',
                [
                    'label' => esc_attr__( 'Images Size', 'gillion' ),
                    'description' => esc_attr__( 'Choose slider style', 'gillion' ),
                    'type' => Controls_Manager::SELECT,
                    'options' => [
                        'large' => esc_attr__( 'Large', 'gillion' ),
                        'full' => esc_attr__( 'Full', 'gillion' ),
                        'gillion-landscape-small' => esc_attr__( 'Landscape', 'gillion' ),
                        'gillion-portrait' => esc_attr__( 'Portrait', 'gillion' ),
                        'gillion-square' => esc_attr__( 'Square', 'gillion' ),
                    ],
                    'default' => 'large',

                ]
            );

            $this->add_control(
                'dots',
                [
                    'label' => esc_attr__( 'Dots', 'gillion' ),
                    'description' => esc_attr__( 'Choose to enable or disable slider dots', 'gillion' ),
                    'type' => Controls_Manager::SWITCHER,
					'return_value' => 'yes',
                    'default' => 'yes',
                    'label_on' => esc_attr__( 'On', 'haste' ),
                    'label_off' => esc_attr__( 'Off', 'haste' ),

                ]
            );

            $this->add_control(
                'autoplay',
                [
                    'label' => esc_attr__( 'Autoplay', 'gillion' ),
                    'description' => esc_attr__( 'Choose to enable or disable slider autoplay', 'gillion' ),
                    'type' => Controls_Manager::SWITCHER,
					'return_value' => 'yes',
                    'default' => 'yes',
                    'label_on' => esc_attr__( 'On', 'haste' ),
                    'label_off' => esc_attr__( 'Off', 'haste' ),

                ]
            );


        $this->end_controls_section();
	}


	/**
	 * Render the widget output on the frontend.
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$settings = (array)$settings;
		$settings['elementor'] = true;
		vcImageGallery::_html( $settings );
	}
}
