<?php
namespace ElementorGillionElements\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Core\Schemes\Typography;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Frontend;
use vcAuthor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor - Blog Posts
 */
class Gillion_Separator_Text extends Widget_Base {

	/**
	 * Adds scripts
	 */
	public function __construct($data = [], $args = null) {
       parent::__construct($data, $args);
    }

	/**
	 * Retrieve the widget name.
	 */
	public function get_name() {
		return 'gillion-separator-text';
	}

	/**
	 * Retrieve the widget title.
	 */
	public function get_title() {
		return esc_attr__( 'Separator With Text', 'gillion' );
	}


	/**
	 * Retrieve the widget icon.
	 */
	public function get_icon() {
		return 'fas fa-heading';
	}


	/**
	 * Retrieve the list of categories the widget belongs to.
	 */
	public function get_categories() {
		return [ 'gillion' ];
	}


	/**
	 * Register the widget controls.
	 */
	protected function register_controls() {
        $this->start_controls_section(
            'section_content',
            [
                'label' => esc_attr__( 'Content', 'gillion' ),
            ]
        );


            $this->add_control(
                'title',
                [
                    'label' => esc_attr__( 'Title', 'haste' ),
                    'type' => Controls_Manager::TEXTAREA ,
                    'rows' => 5,
                    'placeholder' => esc_attr__( 'Type your title here', 'haste' ),
                    'default' => esc_attr__( 'Add Your Text Here', 'haste' ),
                ]
            );

            $this->add_responsive_control(
    			'align',
    			[
    				'label' => esc_attr__( 'Alignment', 'haste' ),
    				'type' => Controls_Manager::CHOOSE,
    				'options' => [
    					'left' => [
    						'title' => esc_attr__( 'Left', 'haste' ),
    						'icon' => 'eicon-text-align-left',
    					],
    					'center' => [
    						'title' => esc_attr__( 'Center', 'haste' ),
    						'icon' => 'eicon-text-align-center',
    					],
    					'right' => [
    						'title' => esc_attr__( 'Right', 'haste' ),
    						'icon' => 'eicon-text-align-right',
    					],
    				],
    				'default' => 'center',
    			]
    		);

            $this->add_control(
				'text_color',
				[
					'label' => esc_attr__( 'Text Color', 'haste' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .text-seperator2-content-heading' => 'color: {{VALUE}}',
					],
				]
			);

            $this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' => 'typography',
					'label' => esc_attr__( 'Typography', 'haste' ),
					'scheme' => Typography::TYPOGRAPHY_1,
					'selector' => '{{WRAPPER}} .text-seperator2-content-heading',
				]
			);

			$this->add_control(
				'line_color',
				[
					'label' => esc_attr__( 'Line Color', 'haste' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .text-seperator2-line' => 'border-color: {{VALUE}}',
					],
				]
			);

			$this->add_responsive_control(
    			'line_size',
    			[
    				'label' => esc_attr__( 'Line Size', 'haste' ),
    				'type' => Controls_Manager::SLIDER,
    				'range' => [
    					'px' => [
    						'min' => 1,
    						'max' => 10,
    					],
    				],
    				'selectors' => [
    					'{{WRAPPER}} .text-seperator2-line' => 'border-width: {{SIZE}}{{UNIT}}; top: calc( ( {{SIZE}}{{UNIT}} / 2 ) * -1 )',
    				],
    			]
    		);


        $this->end_controls_section();
	}


	/**
	 * Render the widget output on the frontend.
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$title = $settings['title'];
		$align = $settings['align'];
		?>

            <div class="text-seperator2 text-seperator2-align-<?php echo esc_attr( $align ); ?>">
                <div class="text-seperator2-holder">
                    <div class="text-seperator2-line"></div>
                </div>
                <div class="text-seperator2-content">
                    <h3 class="text-seperator2-content-heading">
                        <?php echo ( $title ); ?>
                    </h3>
                </div>
                <div class="text-seperator2-holder">
                    <div class="text-seperator2-line"></div>
                </div>
            </div>

		<?php
	}
}
