<?php
namespace ElementorGillionElements\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Core\Schemes\Typography;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Frontend;
use vcSocialNetworks;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor - Blog Posts
 */
class Gillion_Social_Networks extends Widget_Base {

	/**
	 * Adds scripts
	 */
	public function __construct($data = [], $args = null) {
       parent::__construct($data, $args);
    }

	/**
	 * Retrieve the widget name.
	 */
	public function get_name() {
		return 'gillion-social-networks';
	}

	/**
	 * Retrieve the widget title.
	 */
	public function get_title() {
		return esc_attr__( 'Social Networks', 'gillion' );
	}


	/**
	 * Retrieve the widget icon.
	 */
	public function get_icon() {
		return 'fab fa-facebook';
	}


	/**
	 * Retrieve the list of categories the widget belongs to.
	 */
	public function get_categories() {
		return [ 'gillion' ];
	}


	/**
	 * Register the widget controls.
	 */
	protected function register_controls() {
        $this->start_controls_section(
            'section_content',
            [
                'label' => esc_attr__( 'Content', 'gillion' ),
            ]
        );

                $this->add_control(
                    'facebook',
                    [
                        'label' => esc_attr__( 'Facebook', 'gillion' ),
                        'description' => esc_attr__( 'Enter URL to your Facebook profile', 'gillion' ),
                        'type' => Controls_Manager::TEXT,
                    ]
                );

                $this->add_control(
                    'twitter',
                    [
                        'label' => esc_attr__( 'Twitter', 'gillion' ),
                        'description' => esc_attr__( 'Enter URL to your Twitter profile', 'gillion' ),
                        'type' => Controls_Manager::TEXT,
                    ]
                );

                $this->add_control(
                    'tumblr',
                    [
                        'label' => esc_attr__( 'Tumblr', 'gillion' ),
                        'description' => esc_attr__( 'Enter URL to your Tumblr profile', 'gillion' ),
                        'type' => Controls_Manager::TEXT,
                    ]
                );

                $this->add_control(
                    'pinterest',
                    [
                        'label' => esc_attr__( 'Pinterest', 'gillion' ),
                        'description' => esc_attr__( 'Enter URL to your Pinterest profile', 'gillion' ),
                        'type' => Controls_Manager::TEXT,
                    ]
                );



        $this->end_controls_section();
        $this->start_controls_section(
            'styling_section',
            [
                'label' => esc_attr__( 'Styling', 'gillion' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

                $this->add_control(
                    'alignment',
                    [
                        'label' => esc_attr__( 'Alignment', 'gillion' ),
                        'description' => esc_attr__( '', 'gillion' ),
                        'type' => Controls_Manager::SELECT,
                        'options' => [
                            'left' => esc_attr__( 'Left', 'gillion' ),
                            'center' => esc_attr__( 'Center', 'gillion' ),
                            'right' => esc_attr__( 'Right', 'gillion' ),
                        ],
                        'default' => 'left',
                    ]
                );

                $this->add_responsive_control(
                    'el_font_size',
                    [
                        'label' => esc_attr__( 'Font Size', 'gillion' ),
                        'description' => esc_attr__( 'Enter icon font size in px', 'gillion' ),
                        'type' => Controls_Manager::SLIDER,
						'size_units' => [ 'px' ],
						'range' => [
							'px' => [
								'min' => 1,
								'max' => 100,
								'step' => 1,
							],
						],
						'default' => [
							'unit' => 'px',
							'size' => 16,
						],
						'selectors' => [
							'{{WRAPPER}} i' => 'font-size: {{SIZE}}{{UNIT}};',
						],
                    ]
                );

                $this->add_control(
                    'el_icon_color',
                    [
                        'label' => esc_attr__( 'Icon Color', 'gillion' ),
                        'type' => Controls_Manager::COLOR,
						'selectors' => [
							'{{WRAPPER}} i' => 'color: {{VALUE}}',
						],
                    ]
                );


        $this->end_controls_section();
	}


	/**
	 * Render the widget output on the frontend.
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$settings = (array)$settings;
		$settings['elementor'] = true;
		vcSocialNetworks::_html( $settings );
	}
}
