<?php
namespace ElementorGillionElements\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Core\Schemes\Typography;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Frontend;
use vcWooCommerceProducts;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor - Blog Posts
 */
class Gillion_WooCommerce_Products extends Widget_Base {

	/**
	 * Adds scripts
	 */
	public function __construct($data = [], $args = null) {
       parent::__construct($data, $args);
    }

	/**
	 * Retrieve the widget name.
	 */
	public function get_name() {
		return 'gillion-woocommerce-products';
	}

	/**
	 * Retrieve the widget title.
	 */
	public function get_title() {
		return esc_attr__( 'WooCommerce Products', 'gillion' );
	}


	/**
	 * Retrieve the widget icon.
	 */
	public function get_icon() {
		return 'fas fa-shopping-bag';
	}


	/**
	 * Retrieve the list of categories the widget belongs to.
	 */
	public function get_categories() {
		return [ 'gillion' ];
	}


	/**
	 * Register the widget controls.
	 */
	protected function register_controls() {
        $this->start_controls_section(
            'section_content',
            [
                'label' => esc_attr__( 'Content', 'gillion' ),
            ]
        );

                $this->add_control(
                    'posts_per_page',
                    [
                        'label' => esc_attr__( 'Show Posts', 'gillion' ),
                        'description' => esc_attr__( 'Choose how many posts will be shown. Notice: Currently this element works only when using one instance per page', 'gillion' ),
                        'type' => Controls_Manager::TEXT,
                        'default' => '4',
                    ]
                );


                $this->add_control(
                    'load_more',
                    [
                        'label' => esc_attr__( 'Load More Posts Per Page', 'gillion' ),
                        'description' => esc_attr__( 'Choose how many items will be loaded', 'gillion' ),
                        'type' => Controls_Manager::TEXT,
                        'default' => '4',
                    ]
                );


        $this->end_controls_section();
	}


	/**
	 * Render the widget output on the frontend.
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$settings = (array)$settings;
		$settings['elementor'] = true;
		if( class_exists( 'vcWooCommerceProducts' ) ) :
			vcWooCommerceProducts::_html( $settings );
		endif;
	}
}
