<?php
namespace ElementorGillionElements\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Core\Schemes\Typography;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Frontend;
use vcWooCommerceSpotlight;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor - Blog Posts
 */
class Gillion_WooCommerce_Spotlight extends Widget_Base {

	/**
	 * Adds scripts
	 */
	public function __construct($data = [], $args = null) {
       parent::__construct($data, $args);
    }

	/**
	 * Retrieve the widget name.
	 */
	public function get_name() {
		return 'gillion-woocommerce-spotlight';
	}

	/**
	 * Retrieve the widget title.
	 */
	public function get_title() {
		return esc_attr__( 'WooCommerce Spotlight', 'gillion' );
	}


	/**
	 * Retrieve the widget icon.
	 */
	public function get_icon() {
		return 'fas fa-shopping-bag';
	}


	/**
	 * Retrieve the list of categories the widget belongs to.
	 */
	public function get_categories() {
		return [ 'gillion' ];
	}


	/**
	 * Register the widget controls.
	 */
	protected function register_controls() {
        $this->start_controls_section(
            'section_content',
            [
                'label' => esc_attr__( 'Content', 'gillion' ),
            ]
        );


                $this->add_control(
                    'title_new',
                    [
                        'label' => esc_attr__( 'New Products Title', 'gillion' ),
                        'description' => esc_attr__( 'Enter new products title', 'gillion' ),
                        'type' => Controls_Manager::TEXT,
                        'default' => 'New Arrivals',
                    ]
                );

                $this->add_control(
                    'title_featured',
                    [
                        'label' => esc_attr__( 'Featured Products Title', 'gillion' ),
                        'description' => esc_attr__( 'Enter featured products title (featured products can be selected by going to the product list page and clicking on product star icon)', 'gillion' ),
                        'type' => Controls_Manager::TEXT,
                        'default' => 'Featured',
                    ]
                );

                $this->add_control(
                    'title_top',
                    [
                        'label' => esc_attr__( 'Top Selling Products Title', 'gillion' ),
                        'description' => esc_attr__( 'Enter new products title', 'gillion' ),
                        'type' => Controls_Manager::TEXT,
                        'default' => 'Top Selling',
                    ]
                );


        $this->end_controls_section();
	}


	/**
	 * Render the widget output on the frontend.
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$settings = (array)$settings;
		$settings['elementor'] = true;
		if( class_exists( 'vcWooCommerceSpotlight' ) ) :
			vcWooCommerceSpotlight::_html( $settings );
		endif;
	}
}
